/**
 * 
 */
package com.delphigl.dglbenchmark.benchmarks;

import javax.media.opengl.GL;

/**
 * <p>
 * Alle Benchmarkklassen fr den DGL Benchmark mssen dieses Interface
 * implementieren.
 * </p>
 * <p>
 * Weiterhin <b>mssen</b> DGL_Benchmarkklassen diese Formatierungsregeln
 * einhalten:
 * </p>
 * <ul>
 * <li>BenchmarkMethoden starten mit "benchmark_"</li>
 * <li>Fr jede BenchmarkMethode existiert eine BenchmarkSetupMethode mit diesem
 * Namensformat: "setupBenchmark_BENCHMARKNAME"</li>
 * </ul>
 * 
 * @author Kevin Fleischer (aka Flash@DelphiGL.com)
 * 
 */
public interface IDglBenchmark {

	/**
	 * <p>
	 * Der Resultstring enthlt Zeilenumbrche. Jede Zeile enthlt genau einen
	 * Datensatz im Format "BEZEICHNER=WERT". Folgende Bezeichner sind
	 * vorgesehen
	 * </p>
	 * <b>Name</b><br/>
	 * Der Benchmarkname. Sollte eindeutig sein. z.B. durch das Vorranstellen
	 * des DGL-Usernamen (z.B. Flash.ShadingBenchmark) <br/>
	 * <b>Autor</b><br/>
	 * Der/Die Autor(en) <br/>
	 * <b>Version</b><br/>
	 * Version des Vorliegenden Benchmarks. (Die Version ist eine Ganzzahl
	 * beginnend bei 1 . Die Version eines Benchmarks wird immer dann um 1
	 * erhht, wenn eine nderung am Code durchgefhrt wurde die eine
	 * Performancenderung einer der Benchmark-Methoden nach sich ziehen
	 * knnte.) <br/>
	 * <b>Zweck</b><br/>
	 * Der Benchmarkzweck <br/>
	 * <b>Loops</b><br/>
	 * Anzahl der Wiederholungen die zur Messung gemacht werden sollen. Dient
	 * als Parameter fr das Benchmark-Programm. Ganzzahliger Wert. Ist dies
	 * nicht angegeben wird 50 als Standardwert genutzt. Wertebereich: 0 < Loops
	 * <= 1000. <br/>
	 * <b>CanvasSize </b><br/>
	 * Gre des OpenGL-Canvases im Format [Breite]x[Hoehe] in Pixel. Beispiel:
	 * 400x300
	 * <p>
	 * Mindestens enthalten sein muss der Name des Benchmarks, CanvasSize und
	 * die Version.
	 * </p>
	 * 
	 * @return Ein formatierter String mit Informationen ber den Benchmark.
	 */
	public String getBenchmarkInfos();

	/**
	 * Die Validate Methode wird einmalig und vor dem Aufruf der ersten
	 * Setup-Methode aufgerufen.
	 * 
	 * Die Validate Methode prft ob die bentigte mindest-OpenGL-Version
	 * vorhanden ist bzw. ob alle bentigten OpenGL Extensions, die der
	 * Benchmark bentigt, verfgbar sind. Ist dies nicht der Fall liefert die
	 * Funktion eine Beschreibung des Problems (z.B. den Namen der fehlenden
	 * Extension) zurck.
	 * @param gl Das aktuelle OpenGL Objekt.
	 * @return Ein leerer String ("") im Erfolgsfall oder aber eine Beschreibung
	 *         wieso die Validierung fehlschlug.
	 */
	public String validateBenchmark(GL gl);
}
